@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2014-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2014-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * @category  Horde
- * @copyright 2014-2016 Horde LLC
+ * @copyright 2014-2017 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Mime
  */
@@ -16,7 +16,7 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2014-2016 Horde LLC
+ * @copyright 2014-2017 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Mime
  * @since     2.5.0
@@ -142,6 +142,9 @@ implements IteratorAggregate
         }
 
         /* Ensure no null characters exist in header data. */
+		if ($data === null) {
+			return '';
+		}
         return str_replace("\0", '', $data);
     }
 
@@ -173,6 +176,7 @@ implements IteratorAggregate
 
     /**
      */
+	#[ReturnTypeWillChange]
     public function getIterator()
     {
         return new ArrayIterator($this->_values);
